
library ieee;
use ieee.std_logic_1164.all;


entity top_tb is
end entity top_tb;

architecture testbench of top_tb is

    ---------------------------
    -- constant declarations
    constant clk_m49_period : time := 1 sec / 49_152_000;  -- 49 MHz


    ---------------------------
    -- signal declarations
    signal simulation_run : boolean   := true;
    --
    signal tb_m49         : std_logic := '0';
    -- GPIO
    signal tb_sw1         : std_logic;
    signal tb_sw2         : std_logic := '1';
    -- TUSB3410
    signal tb_sin         : std_logic;
    signal tb_sout        : std_logic := '1';
    signal tb_rts         : std_logic := '1';
    signal tb_cts         : std_logic;
    signal tb_vs2         : std_logic;
    signal tb_tvs1        : std_logic;
    -- SPI flash
    signal tb_cso         : std_logic;
    signal tb_tmosi       : std_logic;
    signal tb_tdin        : std_logic;
    signal tb_tcclk       : std_logic;
    -- remaining IO pins
    signal tb_c13         : std_logic := '0';
    signal tb_d13         : std_logic := '0';
    signal tb_tvs0        : std_logic;
    signal tb_tm1         : std_logic;
    signal tb_thsw        : std_logic;
    -- I/O's for DIL / main connector
    signal tb_pin         : std_logic_vector(48 downto 1);


begin


    -- generate clocks
    tb_m49 <= not tb_m49 after clk_m49_period / 2 when simulation_run;

    -- generate reset
    tb_sw1 <= '1', '0' after 6.66 * clk_m49_period;


    -- dut
    top_i0 : entity work.top
        port map (
            m49   => tb_m49 ,  -- : in    std_logic;            -- oscillator input
            -- GPIO
            sw1   => tb_sw1 ,  -- : in    std_logic;            -- switch 1, high active
            sw2   => tb_sw2 ,  -- : in    std_logic;            -- switch 2, low active
            -- TUSB3410
            sin   => tb_sin ,  -- : inout std_logic;            -- M0 configuration pin, TUSB3410 serial data input, LED3
            sout  => tb_sout ,  -- : in    std_logic;            -- TUSB3410 serial data out
            rts   => tb_rts ,  -- : in    std_logic;            -- TUSB3410 ready to send (LED5)
            cts   => tb_cts ,  -- : inout std_logic;            -- TUSB3410 clear to send (and LED6)
            vs2   => tb_vs2 ,  -- : inout std_logic;            -- TUSB3410 I2C connection, LED8
            tvs1  => tb_tvs1 ,  -- : inout std_logic;            -- TUSB3410 I2C connector (and E2)
            -- SPI flash
            cso   => tb_cso ,  -- : inout std_logic;            -- SPI memory chip select
            tmosi => tb_tmosi ,  -- : inout std_logic;            -- SPI memory mosi (and E4)
            tdin  => tb_tdin ,  -- : inout std_logic;            -- SPI memory data out (and E5)
            tcclk => tb_tcclk ,  -- : inout std_logic;            -- SPI memory clock (and E6)
            -- remaining IO pins
            c13   => tb_c13 ,  -- : in    std_logic;            -- external input (pin 49)
            d13   => tb_d13 ,  -- : in    std_logic;            -- external input (pin 50)
            tvs0  => tb_tvs0 ,  -- : inout std_logic;            -- E3
            tm1   => tb_tm1 ,  -- : inout std_logic;            -- M1 configuration pin (and E7)
            thsw  => tb_thsw ,  -- : inout std_logic;            -- HSWAP configuration pin (and E8)
            -- I/O's for DIL / main connector
            pin   => tb_pin  -- : inout std_logic_vector(48 downto 1)
            );

end architecture testbench;
